@@ -4,7 +4,7 @@ __all__ = [
     'flatten','fname','find','fname2','glob','Glob','Image','inspect','jitter', 'L',
     'line','loaddill','logger','extn', 'makedir', 'np', 'now','nunique','os','pad','pd','pdfilter','parent','Path','pdb',
     'plt','PIL','puttext','randint','rand','read','readlines','readPIL','rect','rename_batch','resize','see',
-    'set_logging_level','show','stem','stems','subplots','sys','tqdm','Tqdm','Timer','unique','uint','writelines','zip_files','unzip_file',
+    'set_logging_level','show','stem','stems','subplots','sys','tqdm','Tqdm','Timer','unique','uint','writelines','zip_files','unzip_file','xywh2xyXY',
     'remove_duplicates', 'md5',
     'Info','Warn','Debug','Excep'
 ]
@@ -335,6 +335,8 @@ class BB:
 def subplots(ims, nc=5, figsize=(5,5), **kwargs):
     if len(ims) == 0: return
     titles = kwargs.pop('titles',[None]*len(ims))
+    if isinstance(titles, str):
+        titles = titles.split(',')
     nr = (len(ims)//nc) if len(ims)%nc==0 else (1+len(ims)//nc)
     logger.info(f'plotting {len(ims)} images in a grid of {nr}x{nc} @ {figsize}')
     figsize = kwargs.pop('sz', figsize)
@@ -396,11 +398,11 @@ def resize(im:np.ndarray, sz:[float,('H','W')]):
             H,W = sz
     return cv2.resize(im, (W,H))
 
-def readlines(fpath):
+def readlines(fpath, silent=False):
     with open(fpath, 'r') as f:
         lines = f.read().split('\n')
         lines = [l.strip() for l in lines if l.strip()!='']
-        Info(f'loaded {len(lines)} lines')
+        if not silent: Info(f'loaded {len(lines)} lines')
         return lines
 
 def resize(im:np.ndarray, sz:[float,('H','W'),(str,('H','W'))]):
@@ -447,9 +449,10 @@ def resize(im:np.ndarray, sz:[float,('H','W'),(str,('H','W'))]):
             H,_ = sz
             f = H/h
             W = f*w
-        if isinstance(H, float): H = H*h
-        if isinstance(W, float): W = W*h
+        elif isinstance(H, float): H = H*h
+        elif isinstance(W, float): W = W*h
     H,W = int(H),int(W)
+    print(H,W)
     return cv2.resize(im, (W,H))
 
 def pad(im, sz, pad_value=255):
@@ -498,3 +501,9 @@ def remove_duplicates(files):
     # !rm ./x
     return
 
+
+def xywh2xyXY(bbs):
+    if len(bbs) == 4 and isinstance(bbs[0], int):
+        x,y,w,h = bbs
+        return BBox(x,y,x+w,y+h)
+    return [xywh2xyXY(bb) for bb in bbs]
